@@ -147,6 +147,9 @@ class VoilaHandler(JupyterHandler):
 
         # Compose reply
         self.set_header('Content-Type', 'text/html')
+        self.set_header('Cache-Control', 'no-cache, no-store, must-revalidate')
+        self.set_header('Pragma', 'no-cache')
+        self.set_header('Expires', '0')
         # render notebook in snippets, and flush them out to the browser can render progresssively
         async for html_snippet, resources in self.exporter.generate_from_notebook_node(notebook, resources=resources, extra_context=extra_context):
             self.write(html_snippet)
@@ -167,7 +170,8 @@ class VoilaHandler(JupyterHandler):
         ))
         km = self.kernel_manager.get_kernel(kernel_id)
 
-        self.executor = VoilaExecutor(nb, km=km, config=self.traitlet_config)
+        self.executor = VoilaExecutor(nb, km=km, config=self.traitlet_config,
+                                      show_tracebacks=self.voila_configuration.show_tracebacks)
 
         ###
         # start kernel client
@@ -208,6 +212,7 @@ class VoilaHandler(JupyterHandler):
                 output_cell = input_cell
                 break
             except CellExecutionError:
+                self.log.exception('Error at server while executing cell: %r', input_cell)
                 if self.executor.should_strip_error():
                     strip_code_cell_warnings(input_cell)
                     self.executor.strip_code_cell_errors(input_cell)
